Release notes
=============

0.1
---

Initial release of Django Pydenticon. Implemented features:

* Serving of identicons through designated URL.
* User data for generating identicons passed via URL.
* Sane configuration defaults for identicon generator for zero-configuration.
* Ability to set parameters of generated identicons.
* Ability to override some of the identicon generation attributes per-request
  via *GET* parameters.
* Full documentation covering installation, usage, privacy. API reference
  included as well.
